import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

/**
 * @ngdoc react
 * @name SidePanel
 * @description SidePanel Component used usually for Advanced Search panels
 */
export const SidePanel = ({children, shadowRight, shadowLeft, transparent, bg00, className, testId}) => (
    <div
        className={classNames(
            'side-panel',
            {
                'side-panel--shadow-right': shadowRight,
                'side-panel--transparent': transparent,
                'side-panel--shadow-left': shadowLeft,
                'side-panel--bg-00': bg00,
            },
            className
        )}
        data-test-id={testId}
    >
        {children}
    </div>
);

SidePanel.propTypes = {
    children: PropTypes.node,
    shadowRight: PropTypes.bool,
    shadowLeft: PropTypes.bool,
    transparent: PropTypes.bool,
    bg00: PropTypes.bool,
    className: PropTypes.string,
    testId: PropTypes.string,
};

SidePanel.defaultProps = {
    shadowRight: false,
    shadowLeft: false,
    transparent: false,
    bg00: false,
    className: '',
};
